## Sleep Ensemble Builds

A directory for Sleep Ensemble pre-trained builds.

Currently, `sleepens` uses `joblib` to store the pre-trained builds. To simplify the repository and reduce clutter, pre-trained builds are released as binaries with associated releases and are not stored directly in the source code repository. Hence, the need for a directory of releases where each build can be found.

**Sleep Ensemble 4**

Compatible with the latest release:
* [SleepEnsemble4 1.0.0 for 64bit Windows Python 3.7.8](https://github.com/paradoxysm/sleepens/releases/tag/1.0.0)

Sleep Ensemble 1.0.0:
* [SleepEnsemble4 1.0.0 for 64bit Windows Python 3.7.8](https://github.com/paradoxysm/sleepens/releases/tag/1.0.0)
